# oslg

Python implementation of the _OSlg_ logger for the OpenStudio SDK.

- PyPi [oslg](https://pypi.org/project/oslg/) package
- original Ruby implementation/documentation [here](https://github.com/rd2/oslg)

_Disclaimer: alpha release_
